import { useState, useContext, useMemo, useEffect } from "react";
import { JobDetailsView } from "./JobDetailsView";
import { LinearProgress } from "@mui/material";
import NotFoundView from "../../components/navigation/NotFoundView/NotFoundView";
import { onFetchEntityError } from "../../components/common/Helper";
import { useAPIMethod, usePolling } from "@ess-ics/ce-ui-common";
import { apiContext } from "../../api/DeployApi";

const POLL_DEPLOYMENT_INTERVAL = 5000;
export function JobDetailsContainer({ id }) {
  const [notFoundError, setNotFoundError] = useState();

  const client = useContext(apiContext);

  const jobDetailParams = useMemo(
    () => ({
      job_id: id
    }),
    [id]
  );
  const {
    value: job,
    wrapper: getJob,
    error: jobError
  } = useAPIMethod({
    fcn: client.apis.Jobs.fetchJob,
    call: false,
    params: jobDetailParams
  });

  useEffect(() => {
    if (jobError) {
      onFetchEntityError(jobError?.message, jobError?.status, setNotFoundError);
    }
  }, [jobError]);

  usePolling(getJob, job?.finishedAt, POLL_DEPLOYMENT_INTERVAL);

  return (
    <>
      {notFoundError ? (
        <NotFoundView />
      ) : job ? (
        <JobDetailsView job={job} />
      ) : (
        <LinearProgress color="primary" />
      )}
    </>
  );
}
